=========
Automaton
=========

Friendly state machines for python.

* Free software: Apache license
* Documentation: http://docs.openstack.org/developer/automaton
* Source: http://git.openstack.org/cgit/openstack/automaton
* Bugs: http://bugs.launchpad.net/automaton
